@@ -8,7 +8,7 @@ fn main() {
 		.single_run(env::args().collect::<Vec<String>>());
 }
 
-fn act(c: Context, cmd: Command) -> Result<ActionResult, ActionError> {
+fn act(cmd: Command, c: Context) -> Result<ActionResult, ActionError> {
 	let r = c.get_flag_value_of("reverse", &cmd).unwrap();
 
 	println!(
